@@ -26,13 +26,17 @@ from tempfile import gettempdir
 from os.path import join, abspath, dirname, normpath
 import lino
 
-from lino import Lino
+from lino.ui import Lino
 
-LINO = Lino(__file__,globals())
+#~ class Lino(Lino):
+    #~ pass
+    
+
+#~ 20130219 LINO = Lino(__file__,globals())
 
 #~ DBLOGGER = 'db'
 #~ DBLOGFILE = 'auto'
-USE_FIREBUG = False
+#~ USE_FIREBUG = False
 #~ USE_GRIDFILTERS = True
 #~ MODEL_DEBUG = True
 #~ PROJECT_DIR = normpath(dirname(__file__))
@@ -56,12 +60,6 @@ def TIM2LINO_USERNAME(userid):
     return userid.lower()
     
     
-def TIM2LINO_IS_IMPORTED_PARTNER(obj):
-    "`obj` is either a Person or a Company"
-    #~ return obj.id is not None and (obj.id < 200000 or obj.id > 299999)
-    return False
-    #~ return obj.id is not None and (obj.id > 10 and obj.id < 21)
-              
     
 
 DEBUG = False
@@ -130,15 +128,7 @@ MEDIA_URL = '/media/'
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = 'cqt^18t(Fb#14a@s%mbtdif+ih8fscpf8l9aw+0ivo2!3c(c%&'
 
-# List of callables that know how to import templates from various sources.
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-#     'django.template.loaders.eggs.load_template_source',
-)
-
-
-ROOT_URLCONF = 'lino.ui.extjs3.urls'
+#~ ROOT_URLCONF = 'lino.ui.extjs3.urls'
 
 #~ TEMPLATE_DIRS = [
       #~ join(LINO.project_dir,'templates'),
@@ -146,48 +136,27 @@ ROOT_URLCONF = 'lino.ui.extjs3.urls'
 #~ ]
 #print "baz", __file__
 
-INSTALLED_APPS = [
-  'lino.modlib.users',
-  'lino',
-]
+#~ INSTALLED_APPS = [
+  #~ 'lino.modlib.users',
+  #~ 'lino',
+#~ ]
 
 
 #~ INSTALLED_APPS = []
 
 
 
-SERIALIZATION_MODULES = {
-     #~ "dpy" : "lino.utils.dpy",
-     "py" : "lino.utils.dpy",
-}
 
 #print "done", __file__
 
-TEMPLATE_CONTEXT_PROCESSORS = (
-    #~ 'django.contrib.auth.context_processors.auth',
-    'django.core.context_processors.debug',
-    'django.core.context_processors.i18n',
-    'django.core.context_processors.media',
-    'django.core.context_processors.static',
-#    'django.core.context_processors.request',
-    #~ 'django.contrib.messages.context_processors.messages',
-)
-
-
-LOGIN_URL = '/accounts/login/'
-LOGIN_REDIRECT_URL = "/"
-
 EMAIL_HOST = "mail.example.com"
 #EMAIL_PORT = ""
 
-LOGGING_CONFIG = 'lino.utils.log.configure'
-LOGGING = dict(filename=None,level='INFO')
 
-
-QOOXDOO_PATH = None
-"""
-Path to the Qooxdoo SDK. Used by :term:`makeui`
-"""
+#~ QOOXDOO_PATH = None
+#~ """
+#~ Path to the Qooxdoo SDK. Used by :term:`makeui`
+#~ """
 
 # this setting will be overridden by local settings
 # it is needed for generating docs. Sphinx's autodoc needs to import the modules to introspect them, but Django would complain if no settings is specified.
